@@ -10,10 +10,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import collections
 import logging
 import os.path
 
-import six
 import yaml
 
 from reno import scanner
@@ -21,8 +21,9 @@ from reno import scanner
 LOG = logging.getLogger(__name__)
 
 
-def get_cache_filename(reporoot, notesdir):
-    return os.path.join(reporoot, notesdir, 'reno.cache')
+def get_cache_filename(conf):
+    return os.path.normpath(os.path.join(
+        conf.reporoot, conf.notespath, 'reno.cache'))
 
 
 class Loader(object):
@@ -54,8 +55,7 @@ class Loader(object):
         self._cache = None
         self._scanner = None
         self._scanner_output = None
-        self._cache_filename = get_cache_filename(self._reporoot,
-                                                  self._notespath)
+        self._cache_filename = get_cache_filename(conf)
 
         self._load_data()
 
@@ -66,15 +66,16 @@ class Loader(object):
             LOG.debug('ignoring cache file %s', self._cache_filename)
 
         if (not self._ignore_cache) and cache_file_exists:
+            LOG.debug('loading cache file %s', self._cache_filename)
             with open(self._cache_filename, 'r') as f:
                 self._cache = yaml.safe_load(f.read())
                 # Save the cached scanner output to the same attribute
                 # it would be in if we had loaded it "live". This
                 # simplifies some of the logic in the other methods.
-                self._scanner_output = {
-                    n['version']: n['files']
+                self._scanner_output = collections.OrderedDict(
+                    (n['version'], n['files'])
                     for n in self._cache['notes']
-                }
+                )
         else:
             self._scanner = scanner.Scanner(self._config)
             self._scanner_output = self._scanner.get_notes_by_version()
@@ -101,26 +102,33 @@ class Loader(object):
             body = self._scanner.get_file_at_commit(filename, sha)
             content = yaml.safe_load(body)
 
+        cleaned_content = {}
+
         for section_name, section_content in content.items():
-            if section_name == 'prelude':
-                if not isinstance(section_content, six.string_types):
-                    LOG.warning(
-                        ('The prelude section of %s '
-                         'does not parse as a single string. '
-                         'Is the YAML input escaped properly?') %
-                        filename,
-                    )
-            else:
-                if not isinstance(section_content, list):
+            if section_name == self._config.prelude_section_name:
+                if not isinstance(section_content, str):
                     LOG.warning(
                         ('The %s section of %s '
-                         'does not parse as a list of strings. '
+                         'does not parse as a single string. '
+                         'Is the YAML input escaped properly?') %
+                        (self._config.prelude_section_name, filename),
+                    )
+            else:
+                if isinstance(section_content, str):
+                    # A single string is OK, but wrap it with a list
+                    # so the rest of the code can treat the data model
+                    # consistently.
+                    section_content = [section_content]
+                elif not isinstance(section_content, list):
+                    LOG.warning(
+                        ('The %s section of %s '
+                         'does not parse as a string or list of strings. '
                          'Is the YAML input escaped properly?') % (
                              section_name, filename),
                     )
                 else:
                     for item in section_content:
-                        if not isinstance(item, six.string_types):
+                        if not isinstance(item, str):
                             LOG.warning(
                                 ('The item %r in the %s section of %s '
                                  'parses as a %s instead of a string. '
@@ -128,5 +136,6 @@ class Loader(object):
                                  ) % (item, section_name,
                                       filename, type(item)),
                             )
+            cleaned_content[section_name] = section_content
 
-        return content
+        return cleaned_content
