@@ -12,11 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import mock
+
 from reno.tests import base
 from reno import utils
 
-import mock
-
 
 class TestGetRandomString(base.TestCase):
 
@@ -27,13 +27,15 @@ class TestGetRandomString(base.TestCase):
         randrange.return_value = ord('a')
         actual = utils.get_random_string()
         expected = '61' * 8  # hex for ord('a')
+        self.assertIsInstance(actual, str)
         self.assertEqual(expected, actual)
 
     @mock.patch('random.randrange')
     @mock.patch('os.urandom')
     def test_with_urandom(self, urandom, randrange):
-        urandom.return_value = '\x62' * 8
+        urandom.return_value = b'\x62' * 8
         randrange.return_value = ord('a')
         actual = utils.get_random_string()
         expected = '62' * 8  # hex for ord('b')
+        self.assertIsInstance(actual, str)
         self.assertEqual(expected, actual)
